/**
 * Copyright 2012 Eric Wendelin
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.eriwen.gradle.js.tasks

import org.gradle.api.tasks.TaskAction
import org.gradle.api.DefaultTask
import com.eriwen.gradle.js.ResourceUtil
import java.util.zip.ZipFile

class JsDocTask extends DefaultTask {
    private static final String JSDOC_PATH = 'jsdoc.zip'
    private static final String TMP_DIR = "tmp${File.separator}js"
    private static final ResourceUtil RESOURCE_UTIL = new ResourceUtil()
    private static final String RHINO_MAIN_CLASS = 'org.mozilla.javascript.tools.shell.Main'
    Iterable<String> modulePaths = ['node_modules', 'rhino_modules', '.']
    Iterable<String> options = []
    Boolean debug = false

    @TaskAction
    def run() {
        def outputFiles = getOutputs().files
        if (outputFiles.files.size() == 1) {
            final File zipFile = RESOURCE_UTIL.extractFileToDirectory(new File(project.buildDir, TMP_DIR), JSDOC_PATH)
            final File jsdocDir = RESOURCE_UTIL.extractZipFile(zipFile)
            final String outputPath = (outputFiles.files.toArray()[0] as File).absolutePath
            final String workingDir = "${jsdocDir.absolutePath}${File.separator}jsdoc"

            ant.java(classpath: project.configurations.rhino.asPath, classname: RHINO_MAIN_CLASS, fork: true,
                    dir: workingDir) {
                if (debug) {
                    arg(value: '-debug')
                }
                modulePaths.each { String modulePath ->
                    arg(value: '-modules')
                    arg(value: modulePath)
                }
                arg(value: "${workingDir}${File.separator}jsdoc.js")
                getInputs().files.files.each {
                    arg(value: it.canonicalPath)
                }
                arg(value: '-d')
                arg(value: outputPath)
                options.each {
                    arg(value: it)
                }
            }
        } else {
            throw new IllegalArgumentException('Output must be exactly 1 File object. Example: outputs.dir = file("outputDir")')
        }
    }
}
